==> img0ch-2.1.11.tar.bz2: img0ch/_template/zeromin2/banner_load_sub.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_main&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">メインバナー(主告知欄)</a><br />
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_mobile&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">モバイルバナー(携帯用の告知欄)編集</a><br />
  </div>
</div>

<div id="main">

<form id="bannerSubContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_main&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">バナー編集</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_sub&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">サブバナー(副告知欄)編集</a>
</div>

<h1>サブバナー(副告知欄)編集</h1>

<?cs if:Code0 ?>
<?cs if:Done_banner_save_sub ?><div class="noticeSuccess" id="notify"><p>サブバナー(副告知欄)を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/metadatapreview.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
var formArea;
jQuery(function(){
new Zeromin2.MetadataPreview({
    "content":     "<div class='day' id='subBanner'><div class='body'>"
                   + "<div id='preview' class='section'></div></div></div>",
    "formID":      "bannerSubContainerForm",
    "isTypeTheme": <?cs if:IsTypeTheme ?>true<?cs else ?>false<?cs /if ?>,
    "staticURI":   "<?cs var:html_escape(StaticURI) ?>",
    "typeTheme":   "<?cs var:html_escape(BBS_TYPE_THEME) ?>" });
});
//]]>
</script>

<p>
サブバナー(副告知欄)を編集します。<br />
プレビューを表示させるにはiframeとJavaScriptを有効にする必要があります。
</p>

<p>
<input type="submit" value="更新" />
<a href="javascript:void(0)" onclick="formArea.toggle()">編集フォームを表示または非表示にする</a><br />
<textarea name="content" cols="50" rows="15">
<?cs var:html_escape(Data) ?>
</textarea>
<div id="previewFrame" class="hide"><iframe></iframe></div>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="banner" />
<input type="hidden" name="method" value="save_sub" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_sub" />
<input type="hidden" name="NG" value="load_sub" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/banner_load_sub.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<?cs include:"zeromin2/banner_side_menu.cs" ?>

<div id="main">

<form id="bannerSubContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_main&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">バナー編集</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=banner&amp;method=load_sub&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">サブバナー(副告知欄)編集</a>
</div>

<h1>サブバナー(副告知欄)編集</h1>

<?cs if:Code0 ?>
<?cs if:Done_banner_save_sub ?><div class="noticeSuccess" id="notify"><p>サブバナー(副告知欄)を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/metadatapreview.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
var formArea;
jQuery(function(){
new Zeromin2.MetadataPreview({
    "content":     "<div id='preview'></div>",
    "formID":      "bannerSubContainerForm",
    "isTypeTheme": <?cs if:IsTypeTheme ?>true<?cs else ?>false<?cs /if ?>,
    "staticURI":   "<?cs var:html_escape(StaticURI) ?>",
    "typeTheme":   "<?cs var:html_escape(BBS_TYPE_THEME) ?>" });
});
//]]>
</script>

<p>
サブバナー(副告知欄)を編集します。<br />
プレビューを表示させるにはiframeとJavaScriptを有効にする必要があります。
</p>

<p>
<input type="submit" value="更新" />
<a href="javascript:void(0)" onclick="formArea.toggle()">編集フォームを表示または非表示にする</a><br />
<textarea name="content" cols="50" rows="15">
<?cs var:html_escape(Data) ?>
</textarea>
<div id="previewFrame" class="hide"><iframe></iframe></div>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="banner" />
<input type="hidden" name="method" value="save_sub" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_sub" />
<input type="hidden" name="NG" value="load_sub" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
